@@ -235,6 +235,11 @@ private:
 	void PreeditChangedInlineThis();
 	void PreeditChangedWindowedThis();
 	static void PreeditChanged(GtkIMContext *context, ScintillaGTK *sciThis);
+	bool RetrieveSurroundingThis(GtkIMContext *context);
+	static gboolean RetrieveSurrounding(GtkIMContext *context, ScintillaGTK *sciThis);
+	bool DeleteSurroundingThis(GtkIMContext *context, gint characterOffset, gint characterCount);
+	static gboolean DeleteSurrounding(GtkIMContext *context, gint characterOffset, gint characterCount,
+					  ScintillaGTK *sciThis);
 	void MoveImeCarets(Sci::Position pos);
 	void DrawImeIndicator(int indicator, Sci::Position len);
 	void SetCandidateWindowPos();
