@@ -54,7 +54,6 @@ public:
     void NotifyModified(Document *doc, DocModification mh, void *userData) override;
     void NotifyDeleted(Document *doc, void *userData) noexcept override;
     void NotifyStyleNeeded(Document *doc, void *userData, Sci::Position endPos) override;
-    void NotifyLexerChanged(Document *doc, void *userData) override;
     void NotifyErrorOccurred(Document *doc, void *userData, Status status) override;
 };
 
@@ -85,10 +84,6 @@ void WatcherHelper::NotifyStyleNeeded(Document *, void *, Sci::Position endPos)
     emit owner->style_needed(endPos);
 }
 
-void WatcherHelper::NotifyLexerChanged(Document *, void *) {
-    emit owner->lexer_changed();
-}
-
 void WatcherHelper::NotifyErrorOccurred(Document *, void *, Status status) {
     emit owner->error_occurred(static_cast<int>(status));
 }
