@@ -153,15 +153,15 @@ private:
 
 	QElapsedTimer time;
 
-	int preeditPos;
+	Scintilla::Position preeditPos;
 	QString preeditString;
 
 	int wheelDelta;
 
 	static bool IsHangul(const QChar qchar);
-	void MoveImeCarets(int offset);
+	void MoveImeCarets(Scintilla::Position offset);
 	void DrawImeIndicator(int indicator, int len);
-	Scintilla::KeyMod ModifiersOfKeyboard() const;
+	static Scintilla::KeyMod ModifiersOfKeyboard();
 };
 
 #endif /* SCINTILLAEDITBASE_H */
