@@ -8,14 +8,19 @@
 #ifndef DBCS_H
 #define DBCS_H
 
-#ifdef SCI_NAMESPACE
-namespace Scintilla {
-#endif
+namespace Scintilla::Internal {
+
+constexpr bool IsDBCSCodePage(int codePage) noexcept {
+	return codePage == 932
+	       || codePage == 936
+	       || codePage == 949
+	       || codePage == 950
+	       || codePage == 1361;
+}
+
+bool DBCSIsLeadByte(int codePage, char ch) noexcept;
+bool IsDBCSValidSingleByte(int codePage, int ch) noexcept;
 
-bool DBCSIsLeadByte(int codePage, char ch);
-
-#ifdef SCI_NAMESPACE
 }
-#endif
 
 #endif
