@@ -49,6 +49,8 @@ public:
 	bool hotspotSingleLine;
 	Sci::Position hoverIndicatorPos;
 
+	Scintilla::ChangeHistoryOption changeHistoryOption = Scintilla::ChangeHistoryOption::Disabled;
+
 	// Wrapping support
 	int wrapWidth;
 
@@ -61,15 +63,17 @@ public:
 	EditModel &operator=(const EditModel &) = delete;
 	EditModel &operator=(EditModel &&) = delete;
 	virtual ~EditModel();
-	virtual Sci::Line TopLineOfMain() const = 0;
+	virtual Sci::Line TopLineOfMain() const noexcept = 0;
 	virtual Point GetVisibleOriginInMain() const = 0;
 	virtual Sci::Line LinesOnScreen() const = 0;
 	bool BidirectionalEnabled() const noexcept;
 	bool BidirectionalR2L() const noexcept;
+	SurfaceMode CurrentSurfaceMode() const noexcept;
 	void SetDefaultFoldDisplayText(const char *text);
 	const char *GetDefaultFoldDisplayText() const noexcept;
 	const char *GetFoldDisplayText(Sci::Line lineDoc) const noexcept;
 	InSelection LineEndInSelection(Sci::Line lineDoc) const;
+	[[nodiscard]] int GetMark(Sci::Line line) const;
 };
 
 }
