@@ -66,6 +66,9 @@ public:
 	constexpr bool Intersects(Interval other) const noexcept {
 		return (right > other.left) && (left < other.right);
 	}
+	constexpr Interval Offset(XYPOSITION offset) const noexcept {
+		return {left + offset, right + offset};
+	}
 };
 
 /**
@@ -112,6 +115,10 @@ public:
 		return (right > other.left) && (left < other.right) &&
 			(bottom > other.top) && (top < other.bottom);
 	}
+	constexpr bool Intersects(Interval horizontalBounds) const noexcept {
+		return (right > horizontalBounds.left) && (left < horizontalBounds.right);
+	}
+
 	void Move(XYPOSITION xDelta, XYPOSITION yDelta) noexcept {
 		left += xDelta;
 		top += yDelta;
@@ -119,6 +126,10 @@ public:
 		bottom += yDelta;
 	}
 
+	PRectangle WithHorizontalBounds(Interval horizontal) const noexcept {
+		return PRectangle(horizontal.left, top, horizontal.right, bottom);
+	}
+
 	constexpr PRectangle Inset(XYPOSITION delta) const noexcept {
 		return PRectangle(left + delta, top + delta, right - delta, bottom - delta);
 	}
@@ -200,16 +211,18 @@ public:
 
 	// Red, green and blue values as bytes 0..255
 	constexpr unsigned char GetRed() const noexcept {
-		return co & 0xff;
+		return co & 0xffU;
 	}
 	constexpr unsigned char GetGreen() const noexcept {
-		return (co >> 8) & 0xff;
+		return (co >> 8) & 0xffU;
 	}
 	constexpr unsigned char GetBlue() const noexcept {
-		return (co >> 16) & 0xff;
+		return (co >> 16) & 0xffU;
 	}
 	constexpr unsigned char GetAlpha() const noexcept {
-		return (co >> 24) & 0xff;
+		// Use a temporary here to prevent a 'Wconversion' warning from GCC
+		const int shifted = co >> 24;
+		return shifted & 0xffU;
 	}
 
 	// Red, green, blue, and alpha values as float 0..1.0
