@@ -31,6 +31,7 @@ public:
 	explicit PropSetFile(bool lowerKeys_=false);
 
 	void Set(std::string_view key, std::string_view val);
+	void SetPath(std::string_view key, const FilePath &path);
 	void SetLine(const char *keyVal, bool unescape);
 	void Unset(std::string_view key);
 	bool Exists(const char *key) const;
@@ -54,8 +55,8 @@ public:
 		  FilePathSet *imports, size_t depth);
 	std::string GetWild(const char *keybase, const char *filename);
 	std::string GetNewExpandString(const char *keybase, const char *filename = "");
-	bool GetFirst(const char *&key, const char *&val);
-	bool GetNext(const char *&key, const char *&val);
+	bool GetFirst(const char *&key, const char *&val) const;
+	bool GetNext(const char *&key, const char *&val) const;
 	static void SetCaseSensitiveFilenames(bool caseSensitiveFilenames_) noexcept {
 		caseSensitiveFilenames = caseSensitiveFilenames_;
 	}
