@@ -360,7 +360,7 @@ void SciTEBase::TextRead(FileWorker *pFileWorker) {
 			if (extender)
 				extender->OnOpen(buffers.buffers[iBuffer].file.AsUTF8().c_str());
 			RestoreState(buffers.buffers[iBuffer], true);
-			DisplayAround(buffers.buffers[iBuffer].file);
+			DisplayAround(buffers.buffers[iBuffer].file.filePosition);
 			wEditor.ScrollCaret();
 		}
 	}
@@ -413,8 +413,11 @@ void SciTEBase::CompleteOpen(OpenCompletion oc) {
 
 	if (!wEditor.UndoCollection()) {
 		wEditor.SetUndoCollection(true);
+		wEditor.SetSavePoint();
+		wEditor.SetChangeHistory(static_cast<SA::ChangeHistoryOption>(props.GetInt("change.history")));
+	} else {
+		wEditor.SetSavePoint();
 	}
-	wEditor.SetSavePoint();
 	if (props.GetInt("fold.on.open") > 0) {
 		FoldAll();
 	}
@@ -575,7 +578,7 @@ bool SciTEBase::Open(const FilePath &file, OpenFlags of) {
 	}
 
 	if (buffers.size() == buffers.length) {
-		AddFileToStack(RecentFile(filePath, GetSelectedRange(), GetCurrentScrollPosition()));
+		AddFileToStack(RecentFile(filePath, GetFilePosition()));
 		ClearDocument();
 		CurrentBuffer()->lifeState = Buffer::LifeState::opened;
 		if (extender)
@@ -762,22 +765,78 @@ bool SciTEBase::OpenSelected() {
 	return false;
 }
 
+namespace {
+
+// Find the portions that are the same at the start and end of two string_views.
+// When views equal return (length, 0).
+std::pair<size_t, size_t> CommonEnds(std::string_view a, std::string_view b) noexcept {
+	const size_t length = std::min<size_t>(a.length(), b.length());
+	size_t start = 0;
+	while ((start < length) && (a[start] == b[start])) {
+		start++;
+	}
+	const size_t maxLeft = length - start;
+	size_t last = 0;
+	while ((last < maxLeft) && (a[a.length() - last - 1] == b[b.length() - last - 1])) {
+		last++;
+	}
+	return { start, last };
+}
+
+}
+
 void SciTEBase::Revert() {
 	if (filePath.IsUntitled()) {
 		wEditor.ClearAll();
 	} else {
-		RecentFile rf = GetFilePosition();
-		OpenCurrentFile(filePath.GetFileLength(), false, false);
-		DisplayAround(rf);
+		const FilePosition fp = GetFilePosition();
+		const long long fileLength = filePath.GetFileLength();
+		const UniMode uniMode = CurrentBuffer()->unicodeMode;
+		if ((fileLength < 1000000) && (uniMode == UniMode::cookie || uniMode == UniMode::uni8Bit || uniMode == UniMode::utf8)) {
+			// If short and file and memory use same encoding
+			const std::string contents = filePath.Read();
+			// Check for BOM that matches file mode
+			const std::string_view svUtf8BOM(UTF8BOM);
+			if ((uniMode == UniMode::utf8) && !StartsWith(contents, svUtf8BOM)) {
+				// Should have BOM but doesn't so use full load
+				OpenCurrentFile(fileLength, false, false);
+			} else {
+				std::string_view viewContents = contents;
+				if (uniMode == UniMode::utf8) {
+					// Has BOM but should be omitted in editor
+					viewContents.remove_prefix(svUtf8BOM.length());
+				}
+				const std::string_view doc = TextAsView();
+				const std::pair<size_t, size_t> ends = CommonEnds(doc, viewContents);
+				const size_t start = ends.first;
+				const size_t last = ends.second;
+				if ((viewContents.length() != doc.length()) || (start != doc.length())) {
+					// Truncate and insert
+					wEditor.SetTarget(SA::Span(start, doc.length() - last));
+					const std::string_view changed = viewContents.substr(start, viewContents.size() - last - start);
+					wEditor.ReplaceTarget(changed);
+				}
+				wEditor.SetSavePoint();
+			}
+		} else {
+			OpenCurrentFile(fileLength, false, false);
+		}
+		DisplayAround(fp);
 	}
 }
 
+std::string_view SciTEBase::TextAsView() {
+	const SA::Position length = wEditor.Length();
+	const char *documentMemory = static_cast<const char *>(wEditor.CharacterPointer());
+	return std::string_view(documentMemory, length);
+}
+
 void SciTEBase::CheckReload() {
 	if (props.GetInt("load.on.activate")) {
 		// Make a copy of fullPath as otherwise it gets aliased in Open
 		const time_t newModTime = filePath.ModifiedTime();
 		if ((newModTime != 0) && (newModTime != CurrentBuffer()->fileModTime)) {
-			RecentFile rf = GetFilePosition();
+			const FilePosition fp = GetFilePosition();
 			const OpenFlags of = props.GetInt("reload.preserves.undo") ? ofPreserveUndo : ofNone;
 			if (CurrentBuffer()->isDirty || props.GetInt("are.you.sure.on.reload") != 0) {
 				if ((0 == dialogsOnScreen) && (newModTime != CurrentBuffer()->fileModLastAsk)) {
@@ -794,13 +853,13 @@ void SciTEBase::CheckReload() {
 					const MessageBoxChoice decision = WindowMessageBox(wSciTE, msg, mbsYesNo | mbsIconQuestion);
 					if (decision == MessageBoxChoice::yes) {
 						Open(filePath, static_cast<OpenFlags>(of | ofForceLoad));
-						DisplayAround(rf);
+						DisplayAround(fp);
 					}
 					CurrentBuffer()->fileModLastAsk = newModTime;
 				}
 			} else {
 				Open(filePath, static_cast<OpenFlags>(of | ofForceLoad));
-				DisplayAround(rf);
+				DisplayAround(fp);
 			}
 		}  else if (newModTime == 0 && CurrentBuffer()->fileModTime != 0)  {
 			// Check if the file is deleted
@@ -1077,17 +1136,7 @@ void SciTEBase::EnsureFinalNewLine() {
 		appendNewLine = endDocument > wEditor.LineStart(maxLines - 1);
 	}
 	if (appendNewLine) {
-		const char *eol = "\n";
-		switch (wEditor.EOLMode()) {
-		case SA::EndOfLine::CrLf:
-			eol = "\r\n";
-			break;
-		case SA::EndOfLine::Cr:
-			eol = "\r";
-			break;
-		case SA::EndOfLine::Lf:
-			break;
-		}
+		const char *eol = LineEndString(wEditor.EOLMode());
 		wEditor.InsertText(endDocument, eol);
 	}
 }
@@ -1125,8 +1174,8 @@ bool SciTEBase::SaveBuffer(const FilePath &saveName, SaveFlags sf) {
 			const size_t lengthDoc = LengthDocument();
 			if (!(sf & sfSynchronous)) {
 				wEditor.SetReadOnly(true);
-				const char *documentBytes = static_cast<const char *>(wEditor.CharacterPointer());
-				CurrentBuffer()->pFileWorker = std::make_unique<FileStorer>(this, documentBytes, saveName, lengthDoc, fp, CurrentBuffer()->unicodeMode, (sf & sfProgressVisible));
+				const std::string_view documentBytes = TextAsView();
+				CurrentBuffer()->pFileWorker = std::make_unique<FileStorer>(this, documentBytes, saveName, fp, CurrentBuffer()->unicodeMode, (sf & sfProgressVisible));
 				CurrentBuffer()->pFileWorker->sleepTime = props.GetInt("asynchronous.sleep");
 				if (PerformOnNewThread(CurrentBuffer()->pFileWorker.get())) {
 					retVal = true;
@@ -1493,7 +1542,8 @@ bool SciTEBase::GrepIntoDirectory(const FilePath &directory) {
 	return sDirectory[0] != '.';
 }
 
-void SciTEBase::GrepRecursive(GrepFlags gf, const FilePath &baseDir, const char *searchString, const GUI::gui_char *fileTypes) {
+void SciTEBase::GrepRecursive(GrepFlags gf, const FilePath &baseDir, const char *searchString,
+	GUI::gui_string_view fileTypes, GUI::gui_string_view excludedTypes) {
 	constexpr int checkAfterLines = 10'000;
 	FilePathSet directories;
 	FilePathSet files;
@@ -1503,17 +1553,18 @@ void SciTEBase::GrepRecursive(GrepFlags gf, const FilePath &baseDir, const char
 	for (const FilePath &fPath : files) {
 		if (jobQueue.Cancelled())
 			return;
-		if (*fileTypes == '\0' || fPath.Matches(fileTypes)) {
-			//OutputAppendStringSynchronised(i->AsInternal());
+		if ((fileTypes.empty() || fPath.Matches(fileTypes)) &&
+			((excludedTypes.empty() || !fPath.Matches(excludedTypes)))) {
+			//OutputAppendStringSynchronised(fPath.AsUTF8().c_str());
 			//OutputAppendStringSynchronised("\n");
-			FileReader fr(fPath, gf & grepMatchCase);
-			if ((gf & grepBinary) || !fr.BufferContainsNull()) {
+			FileReader fr(fPath, FlagIsSet(gf, GrepFlags::matchCase));
+			if (FlagIsSet(gf, GrepFlags::binary) || !fr.BufferContainsNull()) {
 				while (const char *line = fr.Next()) {
 					if (((fr.LineNumber() % checkAfterLines) == 0) && jobQueue.Cancelled())
 						return;
 					const char *match = strstr(line, searchString);
 					if (match) {
-						if (gf & grepWholeWord) {
+						if (FlagIsSet(gf, GrepFlags::wholeWord)) {
 							const char *lineEnd = line + strlen(line);
 							while (match) {
 								if (((match == line) || !IsWordCharacter(match[-1])) &&
@@ -1538,22 +1589,25 @@ void SciTEBase::GrepRecursive(GrepFlags gf, const FilePath &baseDir, const char
 		}
 	}
 	if (os.length()) {
-		if (gf & grepStdOut) {
+		if (FlagIsSet(gf, GrepFlags::stdOut)) {
 			fwrite(os.c_str(), os.length(), 1, stdout);
 		} else {
 			OutputAppendStringSynchronised(os.c_str());
 		}
 	}
 	for (const FilePath &fPath : directories) {
-		if ((gf & grepDot) || GrepIntoDirectory(fPath.Name())) {
-			GrepRecursive(gf, fPath, searchString, fileTypes);
+		if (FlagIsSet(gf, GrepFlags::dot) || GrepIntoDirectory(fPath.Name())) {
+			if ((excludedTypes.empty() || !fPath.Matches(excludedTypes))) {
+				GrepRecursive(gf, fPath, searchString, fileTypes, excludedTypes);
+			}
 		}
 	}
 }
 
-void SciTEBase::InternalGrep(GrepFlags gf, const GUI::gui_char *directory, const GUI::gui_char *fileTypes, const char *search, SA::Position &originalEnd) {
+void SciTEBase::InternalGrep(GrepFlags gf, const FilePath &directory, GUI::gui_string_view fileTypes, GUI::gui_string_view excludedTypes,
+	std::string_view search, SA::Position &originalEnd) {
 	GUI::ElapsedTime commandTime;
-	if (!(gf & grepStdOut)) {
+	if (!FlagIsSet(gf, GrepFlags::stdOut)) {
 		std::string os;
 		os.append(">Internal search for \"");
 		os.append(search);
@@ -1565,11 +1619,11 @@ void SciTEBase::InternalGrep(GrepFlags gf, const GUI::gui_char *directory, const
 		originalEnd += os.length();
 	}
 	std::string searchString(search);
-	if (!(gf & grepMatchCase)) {
+	if (!FlagIsSet(gf, GrepFlags::matchCase)) {
 		LowerCaseAZ(searchString);
 	}
-	GrepRecursive(gf, FilePath(directory), searchString.c_str(), fileTypes);
-	if (!(gf & grepStdOut)) {
+	GrepRecursive(gf, directory, searchString.c_str(), fileTypes, excludedTypes);
+	if (!FlagIsSet(gf, GrepFlags::stdOut)) {
 		std::string sExitMessage(">");
 		if (jobQueue.TimeCommands()) {
 			sExitMessage += "    Time: ";
