@@ -355,6 +355,8 @@ void SciTEBase::SetOneStyle(GUI::ScintillaWindow &win, int style, const StyleDef
 		win.StyleSetVisible(style, sd.visible);
 	if (sd.specified & StyleDefinition::sdChangeable)
 		win.StyleSetChangeable(style, sd.changeable);
+	if (sd.specified & StyleDefinition::sdInvisibleRep)
+		win.StyleSetInvisibleRepresentation(style, sd.invisibleRep.c_str());
 	win.StyleSetCharacterSet(style, characterSet);
 }
 
@@ -397,8 +399,8 @@ void SciTEBase::SetMarkerFromProperty(GUI::ScintillaWindow &win, int marker, con
 	if (!markerString.empty()) {
 		MarkerDefinition markerValue(markerString);
 		win.MarkerDefine(marker, markerValue.style);
-		win.MarkerSetFore(marker, markerValue.colour);
-		win.MarkerSetBack(marker, markerValue.back);
+		win.MarkerSetForeTranslucent(marker, markerValue.colour);
+		win.MarkerSetBackTranslucent(marker, markerValue.back);
 	}
 }
 
@@ -608,6 +610,7 @@ static const char *propertiesToForward[] = {
 	"lexer.python.strings.over.newline",
 	"lexer.python.strings.u",
 	"lexer.python.unicode.identifiers",
+	"lexer.r.escape.sequence",
 	"lexer.rust.fold.at.else",
 	"lexer.sql.allow.dotted.word",
 	"lexer.sql.backticks.identifier",
@@ -1271,7 +1274,7 @@ void SciTEBase::ReadProperties() {
 		const char *propName;
 		PreProc ppc;
 	};
-	PropToPPC propToPPC[] = {
+	const PropToPPC propToPPC[] = {
 		{"preprocessor.start.", PreProc::Start},
 		{"preprocessor.middle.", PreProc::Middle},
 		{"preprocessor.end.", PreProc::End},
