@@ -22,9 +22,10 @@ public:
 	Scintilla::CaseVisible caseForce;
 	bool visible;
 	bool changeable;
+	std::string invisibleRep;
 	enum flags { sdNone = 0, sdFont = 0x1, sdSize = 0x2, sdFore = 0x4, sdBack = 0x8,
 		     sdWeight = 0x10, sdItalics = 0x20, sdEOLFilled = 0x40, sdUnderlined = 0x80,
-		     sdCaseForce = 0x100, sdVisible = 0x200, sdChangeable = 0x400
+		     sdCaseForce = 0x100, sdVisible = 0x200, sdChangeable = 0x400, sdInvisibleRep=0x800
 		   } specified;
 	explicit StyleDefinition(std::string_view definition);
 	bool ParseStyleDefinition(std::string_view definition);
@@ -57,4 +58,12 @@ struct IndicatorDefinition {
 	bool ParseIndicatorDefinition(std::string_view definition);
 };
 
+struct MarkerDefinition {
+	Scintilla::MarkerSymbol style;
+	Scintilla::Colour colour;
+	Scintilla::Colour back = ColourRGB(0xFF,0xFF,0xFF);
+	explicit MarkerDefinition(std::string_view definition);
+	bool ParseMarkerDefinition(std::string_view definition);
+};
+
 #endif
