@@ -1,4 +1,6 @@
-// Unit Tests for Scintilla internal data structures
+/** @file unitTest.cxx
+ ** Unit Tests for Scintilla internal data structures
+ **/
 
 /*
     Currently tested:
@@ -29,7 +31,6 @@
         OptionSet
         PropSetSimple
         StyleContext
-        WordList
 */
 
 #include <cstdio>
@@ -37,9 +38,10 @@
 
 #include <string_view>
 #include <vector>
+#include <optional>
 #include <memory>
 
-#include "Platform.h"
+#include "Debugging.h"
 
 #if defined(__GNUC__)
 // Want to avoid misleading indentation warnings in catch.hpp but the pragma
@@ -54,16 +56,16 @@
 #define CATCH_CONFIG_MAIN  // This tells Catch to provide a main() - only do this in one cpp file
 #include "catch.hpp"
 
-using namespace Scintilla;
+using namespace Scintilla::Internal;
 
 // Needed for PLATFORM_ASSERT in code being tested
 
-void Platform::Assert(const char *c, const char *file, int line) {
+void Platform::Assert(const char *c, const char *file, int line) noexcept {
 	fprintf(stderr, "Assertion [%s] failed at %s %d\n", c, file, line);
 	abort();
 }
 
-void Platform::DebugPrintf(const char *format, ...) {
+void Platform::DebugPrintf(const char *format, ...) noexcept {
 	char buffer[2000];
 	va_list pArguments;
 	va_start(pArguments, format);
