@@ -324,7 +324,8 @@ int CodePageFromName(const std::string &encodingName) {
 	struct Encoding {
 		const char *name;
 		int codePage;
-	} knownEncodings[] = {
+	};
+	const Encoding	knownEncodings[] = {
 		{ "ascii", CP_UTF8 },
 		{ "utf-8", CP_UTF8 },
 		{ "latin1", 1252 },
@@ -763,16 +764,6 @@ void SciTEWin::Command(WPARAM wParam, LPARAM lParam) {
 		Activate(lParam);
 		break;
 
-	case IDM_FINISHEDEXECUTE: {
-			jobQueue.SetExecuting(false);
-			if (needReadProperties)
-				ReadProperties();
-			CheckMenus();
-			jobQueue.ClearJobs();
-			CheckReload();
-		}
-		break;
-
 	case IDM_ONTOP:
 		topMost = (topMost ? false : true);
 		::SetWindowPos(MainHWND(), (topMost ? HWND_TOPMOST : HWND_NOTOPMOST), 0, 0, 0, 0, SWP_NOMOVE + SWP_NOSIZE);
@@ -846,7 +837,6 @@ void SciTEWin::ResetExecution() {
 	CheckReload();
 	CheckMenus();
 	jobQueue.ClearJobs();
-	::SendMessage(MainHWND(), WM_COMMAND, IDM_FINISHEDEXECUTE, 0);
 }
 
 void SciTEWin::ExecuteNext() {
@@ -1330,19 +1320,20 @@ void SciTEWin::Execute() {
 	cmdWorker.outputScroll = props.GetInt("output.scroll", 1);
 	cmdWorker.originalEnd = wOutput.Length();
 	cmdWorker.commandTime.Duration(true);
-	cmdWorker.flags = jobQueue.jobQueue[cmdWorker.icmd].flags;
+	const Job job = jobQueue.jobQueue[cmdWorker.icmd];
+	cmdWorker.flags = job.flags;
 	if (scrollOutput)
 		wOutput.GotoPos(wOutput.Length());
 
-	if (jobQueue.jobQueue[cmdWorker.icmd].jobType == JobSubsystem::extension) {
+	if (job.jobType == JobSubsystem::extension) {
 		// Execute extensions synchronously
-		if (jobQueue.jobQueue[cmdWorker.icmd].flags & jobGroupUndo)
+		if (job.flags & jobGroupUndo)
 			wEditor.BeginUndoAction();
 
 		if (extender)
-			extender->OnExecute(jobQueue.jobQueue[cmdWorker.icmd].command.c_str());
+			extender->OnExecute(job.command.c_str());
 
-		if (jobQueue.jobQueue[cmdWorker.icmd].flags & jobGroupUndo)
+		if (job.flags & jobGroupUndo)
 			wEditor.EndUndoAction();
 
 		ExecuteNext();
