@@ -46,7 +46,7 @@ void SciTEWin::SetFileProperties(
 		if (attr & FILE_ATTRIBUTE_SYSTEM) {
 			fa += "S";
 		}
-		ps.Set("FileAttr", fa.c_str());
+		ps.Set("FileAttr", fa);
 	} else {
 		/* Reset values for new buffers with no file */
 		ps.Set("FileTime", "");
@@ -178,7 +178,7 @@ void SciTEWin::Notify(SCNotification *notification) {
 	case TCN_SELCHANGE:
 		// Change of tab
 		if (notification->nmhdr.idFrom == IDM_TABWIN) {
-			const int index = TabCtrl_GetCurSel(HwndOf(wTabBar));
+			const BufferIndex index = TabCtrl_GetCurSel(HwndOf(wTabBar));
 			SetDocumentAt(index);
 			CheckReload();
 		}
