@@ -5,8 +5,8 @@
 // Copyright 1998-2003 by Neil Hodgson <neilh@scintilla.org>
 // The License.txt file describes the conditions under which this software may be distributed.
 
-#include <stdlib.h>
-#include <string.h>
+#include <cstdlib>
+#include <cstring>
 
 #include <string>
 
@@ -46,7 +46,7 @@ bool UniqueInstance::AcceptToOpenFiles(bool bAccept) {
 		// The mutex object is destroyed when its last handle has been closed."
 		// If the mutex already exists, the new process get a handle on it, so even if the first
 		// process exits, the mutex isn't destroyed, until all SciTE instances exit.
-		mutex = ::CreateMutex(NULL, FALSE, mutexName.c_str());
+		mutex = ::CreateMutex(nullptr, FALSE, mutexName.c_str());
 		// The call fails with ERROR_ACCESS_DENIED if the mutex was
 		// created in a different user session because of passing
 		// NULL for the SECURITY_ATTRIBUTES on mutex creation
@@ -169,12 +169,12 @@ bool UniqueInstance::FindOtherInstance() {
 	return false;
 }
 
-void UniqueInstance::WindowCopyData(const char *s, size_t len) {
-	std::string sCopy(s, s + len);	// Ensure NUL at end of string
-	COPYDATASTRUCT cds;
+void UniqueInstance::WindowCopyData(std::string_view s) {
+	std::string sCopy(s);	// Ensure NUL at end of string
+	COPYDATASTRUCT cds {};
 	cds.dwData = 0;
-	cds.cbData = static_cast<DWORD>(len);
-	cds.lpData = &sCopy[0];
+	cds.cbData = static_cast<DWORD>(sCopy.length() + 1);
+	cds.lpData = sCopy.data();
 	::SendMessage(hOtherWindow, WM_COPYDATA, 0, reinterpret_cast<LPARAM>(&cds));
 }
 
@@ -193,21 +193,23 @@ void UniqueInstance::SendCommands(const char *cmdLine) {
 	}
 	::SetForegroundWindow(hOtherWindow);
 
-	// Send 2 messages - first the CWD, so paths relative to
-	// the new instance can be resolved in the old instance,
-	// then the real command line.
-	// (Restoring the cwd could be done,
-	// but keeping it to the last file opened can also
-	// be useful)
+	// Send 3 messages:
+	// 1) first the cwd, so paths relative to the new instance can be
+	// resolved in the old instance,
+	// 2) then the real command line,
+	// 3) then setdefaultcwd to set a reasonable default cwd and prevent
+	// locking of directories.
 	std::string cwdCmd("\"-cwd:");
 	FilePath cwd = FilePath::GetWorkingDirectory();
-	cwdCmd.append(cwd.AsUTF8().c_str());
+	cwdCmd.append(cwd.AsUTF8());
 	cwdCmd.append("\"");
 	// Defeat the "\" mangling - convert "\" to "/"
 	std::replace(cwdCmd.begin(), cwdCmd.end(), '\\', '/');
-	WindowCopyData(cwdCmd.c_str(), cwdCmd.length() + 1);
+	WindowCopyData(cwdCmd);
 	// Now the command line itself.
-	WindowCopyData(cmdLine, strlen(cmdLine) + 1);
+	WindowCopyData(cmdLine);
+	// Restore default working directory
+	WindowCopyData("-setdefaultcwd:");
 }
 
 /**
